@@ -137,7 +137,7 @@ use warnings;
 
 use base qw{ Astro::Coord::ECI::TLE };
 
-our $VERSION = '0.103';
+our $VERSION = '0.104';
 
 use Astro::Coord::ECI::Utils 0.091 qw{:all};
 use Carp;
@@ -1681,7 +1681,7 @@ sub _set_operational_status {
 # All Iridium Classic satellites.
 #
 # Generated by Astro::SpaceTrack tools/all_iridium_classic -tle -indent=0
-# on Thu Aug 16 15:09:04 2018 GMT
+# on Sat Aug 25 17:44:14 2018 GMT
 
 __PACKAGE__->status( clear => 'iridium' );
 __PACKAGE__->status( add => 24792, iridium => 'D', 'Iridium 8', 'Decayed 2017-11-24' );
@@ -1690,7 +1690,7 @@ __PACKAGE__->status( add => 24794, iridium => 'D', 'Iridium 6', 'Decayed 2017-12
 __PACKAGE__->status( add => 24795, iridium => '-', 'Iridium 5', 'Tumbling' );
 __PACKAGE__->status( add => 24796, iridium => '-', 'Iridium 4', 'Tumbling' );
 __PACKAGE__->status( add => 24836, iridium => '-', 'Iridium 914', 'Tumbling' );
-__PACKAGE__->status( add => 24837, iridium => 'S', 'Iridium 12', '' );
+__PACKAGE__->status( add => 24837, iridium => '-', 'Iridium 12', 'Tumbling' );
 __PACKAGE__->status( add => 24838, iridium => 'D', 'Iridium 9', 'Decayed 2003-03-11' );
 __PACKAGE__->status( add => 24839, iridium => '+', 'Iridium 10', '' );
 __PACKAGE__->status( add => 24840, iridium => 'D', 'Iridium 13', 'Decayed 2018-04-29' );
@@ -1699,7 +1699,7 @@ __PACKAGE__->status( add => 24842, iridium => '-', 'Iridium 911', 'Tumbling' );
 __PACKAGE__->status( add => 24869, iridium => 'S', 'Iridium 15', '' );
 __PACKAGE__->status( add => 24870, iridium => '-', 'Iridium 17', 'Tumbling' );
 __PACKAGE__->status( add => 24871, iridium => '-', 'Iridium 920', 'Tumbling' );
-__PACKAGE__->status( add => 24872, iridium => '-', 'Iridium 18', 'Tumbling' );
+__PACKAGE__->status( add => 24872, iridium => 'D', 'Iridium 18', 'Decayed 2018-08-19' );
 __PACKAGE__->status( add => 24873, iridium => '-', 'Iridium 921', 'Tumbling' );
 __PACKAGE__->status( add => 24903, iridium => '-', 'Iridium 26', 'Tumbling' );
 __PACKAGE__->status( add => 24904, iridium => 'D', 'Iridium 25', 'Decayed 2018-05-14' );
@@ -1729,11 +1729,11 @@ __PACKAGE__->status( add => 25077, iridium => '-', 'Iridium 42', 'Tumbling' );
 __PACKAGE__->status( add => 25078, iridium => '-', 'Iridium 44', 'Tumbling' );
 __PACKAGE__->status( add => 25104, iridium => '+', 'Iridium 45', '' );
 __PACKAGE__->status( add => 25105, iridium => '-', 'Iridium 24', 'Tumbling' );
-__PACKAGE__->status( add => 25106, iridium => 'S', 'Iridium 47', '' );
+__PACKAGE__->status( add => 25106, iridium => '-', 'Iridium 47', 'Tumbling' );
 __PACKAGE__->status( add => 25107, iridium => 'D', 'Iridium 48', 'Decayed 2001-05-05' );
 __PACKAGE__->status( add => 25108, iridium => 'D', 'Iridium 49', 'Decayed 2018-02-13' );
 __PACKAGE__->status( add => 25169, iridium => '+', 'Iridium 52', '' );
-__PACKAGE__->status( add => 25170, iridium => '+', 'Iridium 56', '' );
+__PACKAGE__->status( add => 25170, iridium => 'S', 'Iridium 56', '' );
 __PACKAGE__->status( add => 25171, iridium => '+', 'Iridium 54', '' );
 __PACKAGE__->status( add => 25172, iridium => '+', 'Iridium 50', '' );
 __PACKAGE__->status( add => 25173, iridium => '+', 'Iridium 53', '' );
@@ -1748,7 +1748,7 @@ __PACKAGE__->status( add => 25285, iridium => 'S', 'Iridium 62', '' );
 __PACKAGE__->status( add => 25286, iridium => '-', 'Iridium 63', 'Tumbling' );
 __PACKAGE__->status( add => 25287, iridium => 'S', 'Iridium 64', '' );
 __PACKAGE__->status( add => 25288, iridium => 'D', 'Iridium 65', 'Decayed 2018-07-19' );
-__PACKAGE__->status( add => 25289, iridium => '-', 'Iridium 66', 'Tumbling' );
+__PACKAGE__->status( add => 25289, iridium => 'D', 'Iridium 66', 'Decayed 2018-08-23' );
 __PACKAGE__->status( add => 25290, iridium => 'D', 'Iridium 67', 'Decayed 2018-07-02' );
 __PACKAGE__->status( add => 25291, iridium => 'D', 'Iridium 68', 'Decayed 2018-06-06' );
 __PACKAGE__->status( add => 25319, iridium => '-', 'Iridium 69', 'Tumbling' );
@@ -1766,7 +1766,7 @@ __PACKAGE__->status( add => 25469, iridium => 'D', 'Iridium 80', 'Decayed 2018-0
 __PACKAGE__->status( add => 25470, iridium => 'D', 'Iridium 79', 'Decayed 2000-11-29' );
 __PACKAGE__->status( add => 25471, iridium => 'D', 'Iridium 77', 'Decayed 2017-09-22' );
 __PACKAGE__->status( add => 25527, iridium => '-', 'Iridium 2', 'Tumbling' );
-__PACKAGE__->status( add => 25528, iridium => '+', 'Iridium 86', '' );
+__PACKAGE__->status( add => 25528, iridium => 'S', 'Iridium 86', '' );
 __PACKAGE__->status( add => 25529, iridium => 'D', 'Iridium 85', 'Decayed 2000-12-30' );
 __PACKAGE__->status( add => 25530, iridium => '+', 'Iridium 84', '' );
 __PACKAGE__->status( add => 25531, iridium => '+', 'Iridium 83', '' );
@@ -1780,13 +1780,13 @@ __PACKAGE__->status( add => 27374, iridium => 'D', 'Iridium 94', 'Decayed 2018-0
 __PACKAGE__->status( add => 27375, iridium => '+', 'Iridium 95', '' );
 __PACKAGE__->status( add => 27376, iridium => '-', 'Iridium 96', 'Tumbling' );
 __PACKAGE__->status( add => 27450, iridium => 'S', 'Iridium 97', '' );
-__PACKAGE__->status( add => 27451, iridium => '-', 'Iridium 98', 'Tumbling' );
+__PACKAGE__->status( add => 27451, iridium => 'D', 'Iridium 98', 'Decayed 2018-08-24' );
 
 # Summary:
-# Operational [+]: 17
+# Operational [+]: 15
 #       Spare [S]: 13
-#    Tumbling [-]: 38
-#     Decayed [D]: 29
+#    Tumbling [-]: 37
+#     Decayed [D]: 32
 
 1;
 
